@@ -32,14 +32,12 @@
 #include "audiofile.h"
 #include "afinternal.h"
 
-void _af_printid (uint32_t id);
 void _af_print_filehandle (AFfilehandle filehandle);
 void _af_print_tracks (AFfilehandle filehandle);
 void _af_print_channel_matrix (double *matrix, int fchans, int vchans);
 void _af_print_pvlist (AUpvlist list);
 
-void _af_print_audioformat (_AudioFormat *format);
-void _af_print_chunk (_AFchunk *chunk);
+void _af_print_audioformat (AudioFormat *format);
 void _af_print_frame (AFframecount frameno, double *frame, int nchannels,
 	char *formatstring, int numberwidth,
 	double slope, double intercept, double minclip, double maxclip);
