@@ -13,8 +13,8 @@
 	Library General Public License for more details.
 
 	You should have received a copy of the GNU Library General Public
-	License along with this library; if not, write to the 
-	Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
+	License along with this library; if not, write to the
+	Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 	Boston, MA  02111-1307  USA.
 */
 
@@ -28,7 +28,15 @@
 #ifndef EXTENDED_H
 #define EXTENDED_H
 
-void ConvertToIeeeExtended (double num, unsigned char *bytes);
-double ConvertFromIeeeExtended (const unsigned char *bytes);
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+void _af_convert_to_ieee_extended (double num, unsigned char *bytes);
+double _af_convert_from_ieee_extended (const unsigned char *bytes);
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif
