@@ -83,6 +83,12 @@ int main (int argc, char **argv)
 	testalaw(AF_FILE_AIFFC);
 	printf("writealaw: testing WAVE.\n");
 	testalaw(AF_FILE_WAVE);
+	printf("writealaw: testing IRCAM.\n");
+	testalaw(AF_FILE_IRCAM);
+	printf("writealaw: testing VOC.\n");
+	testalaw(AF_FILE_VOC);
+	printf("writealaw: testing CAF.\n");
+	testalaw(AF_FILE_CAF);
 
 	printf("writealaw test passed.\n");
 
