@@ -46,6 +46,7 @@
 #include <audiofile.h>
 #endif
 
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -82,6 +83,12 @@ int main (int argc, char **argv)
 	testulaw(AF_FILE_AIFFC);
 	printf("writeulaw: testing WAVE.\n");
 	testulaw(AF_FILE_WAVE);
+	printf("writeulaw: testing IRCAM.\n");
+	testulaw(AF_FILE_IRCAM);
+	printf("writeulaw: testing VOC.\n");
+	testulaw(AF_FILE_VOC);
+	printf("writeulaw: testing CAF.\n");
+	testulaw(AF_FILE_CAF);
 
 	printf("writeulaw test passed.\n");
 
@@ -92,9 +99,9 @@ void testulaw (int fileFormat)
 {
 	AFfilehandle	file;
 	AFfilesetup	setup;
-	u_int16_t	samples[] = {8, 16, 80, 120, 180, 780, 924, 988,
+	uint16_t	samples[] = {8, 16, 80, 120, 180, 780, 924, 988,
 			1116, 1436, 1884, 8828, 9852, 15996, 19836, 32124};
-	u_int16_t	readsamples[SAMPLE_COUNT];
+	uint16_t	readsamples[SAMPLE_COUNT];
 	AFframecount	framesWritten, framesRead;
 	int		i;
 
